@@ -21,8 +21,14 @@ module Enumerize
           require 'enumerize/hooks/uniqueness'
 
           unless options[:multiple]
-            decorate_attribute_type(name, :enumerize) do |subtype|
-              Type.new(enumerized_attributes[name], subtype)
+            if ::ActiveRecord.version >= ::Gem::Version.new("6.1.0.alpha")
+              decorate_attribute_type(name.to_s) do |subtype|
+                Type.new(enumerized_attributes[name], subtype)
+              end
+            else
+              decorate_attribute_type(name, :enumerize) do |subtype|
+                Type.new(enumerized_attributes[name], subtype)
+              end
             end
           end
         end
