@@ -13,6 +13,7 @@ ActiveRecord::Base.connection.instance_eval do
     t.string :sex
     t.string :role
     t.string :account_type
+    t.string :status
   end
 end
 
@@ -22,6 +23,7 @@ class User < ActiveRecord::Base
   enumerize :sex, :in => [:male, :female], scope: true
   enumerize :role, :in => [:user, :admin], scope: :having_role
   enumerize :account_type, :in => [:basic, :premium]
+  enumerize :status, :in => [:active, :disabled], scope: :shallow
 end
 
 RSpec.describe Enumerize::Integrations::RSpec::Matcher do
@@ -41,7 +43,6 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe 'without qualifier' do
-
     it 'accepts when has defined a enumerize' do
       model.enumerize(:sex, :in => [:male, :female])
       expect(subject).to enumerize(:sex)
@@ -56,9 +57,7 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe '#in' do
-
     context 'defined as array' do
-
       before do
         model.enumerize(:sex, :in => [:male, :female])
       end
@@ -91,7 +90,6 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
     end
 
     context 'defined as hash' do
-
       before do
         model.enumerize(:sex, :in => { male: 0, female: 1 })
       end
@@ -130,7 +128,6 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe '#with_default' do
-
     before do
       model.enumerize(:sex, :in => [:male, :female], default: :female)
     end
@@ -161,9 +158,7 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe '#with_i18n_scope' do
-
     context 'defined as string' do
-
       before do
         model.enumerize(:sex, :in => [:male, :female], i18n_scope: 'sex')
       end
@@ -200,7 +195,6 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe '#with_predicates' do
-
     it 'accepts when predicates is defined as a boolean' do
       model.enumerize(:sex, :in => [:male, :female], predicates: true)
       expect(subject).to enumerize(:sex).in(:male, :female).with_predicates(true)
@@ -211,6 +205,11 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
       expect(subject).to enumerize(:sex).in(:male, :female).with_predicates(prefix: true)
     end
 
+    it 'accepts when custom values are used as attribute' do
+      model.enumerize(:sex, :in => { male: 0, female: 1 }, predicates: true)
+      expect(subject).to enumerize(:sex).in(:male, :female).with_predicates(true)
+    end
+
     it 'rejects when predicates is not defined' do
       model.enumerize(:sex, :in => [:male, :female])
       message = 'Expected Model to define enumerize :sex in: "female", "male" predicates: true'
@@ -221,7 +220,6 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe '#with_multiple' do
-
     it 'accepts when has defined the multiple' do
       model.enumerize(:sex, :in => [:male, :female], multiple: true)
       expect(subject).to enumerize(:sex).in(:male, :female).with_multiple(true)
@@ -237,7 +235,6 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
   end
 
   describe '#with_scope' do
-
     subject do
       User.new
     end
@@ -250,6 +247,10 @@ RSpec.describe Enumerize::Integrations::RSpec::Matcher do
       expect(subject).to enumerize(:role).in(:user, :admin).with_scope(scope: :having_role)
     end
 
+    it 'accepts shallow scope' do
+      expect(subject).to enumerize(:status).in(:active, :disabled).with_scope(:shallow)
+    end
+
     it 'rejects when scope is not defined' do
       message = 'Expected User to define enumerize :account_type in: "basic", "premium" scope: true'
       expect do
